@@ -55,33 +55,6 @@ def get_orgs(username, auth):
     return _getter(url, auth)
 
 
-def get_issues(username, repo, auth):
-    """ username and repo should be strings
-    auth should be a tuple of username and password.
-    """
-
-    tmpl = "https://api.github.com/repos/{username}/{repo}/issues?per_page=100"
-    url = tmpl.format(username=username, repo=repo)
-    return _getter(url, auth)
-
-
-def get_comments(username, repo, number, auth):
-    tmpl = "https://api.github.com/repos/{username}/{repo}/issues/" + \
-        "{number}/comments?per_page=100"
-    url = tmpl.format(username=username, repo=repo, number=number)
-    return _getter(url, auth)
-
-
-def get_pulls(username, repo, auth):
-    """ username and repo should be strings
-    auth should be a tuple of username and password.
-    """
-
-    tmpl = "https://api.github.com/repos/{username}/{repo}/pulls?per_page=100"
-    url = tmpl.format(username=username, repo=repo)
-    return _getter(url, auth)
-
-
 def _getter(url, auth):
     """ Pagination utility.  Obnoxious. """
 
